# A few useful macros
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%global desktopvendor	fedora
%global bt_dir		%{_localstatedir}/lib/bittorrent
%global bt_datadir	%{bt_dir}/data
%global bt_statedir	%{bt_dir}/state
%global pkidir		%{_sysconfdir}/pki

Summary:	BitTorrent swarming network file transfer tool
Name:		bittorrent
Version:	4.4.0
Release:	13%{?dist}
Group:		Applications/Internet
License:	BitTorrent
URL:		http://www.bittorrent.com/
Source0:	http://download.bittorrent.com/dl/BitTorrent-%{version}.tar.gz
Source1:	bittorrent.desktop
Source3:	btseed.init
Source4:	bttrack.init
Source5:	bittorrent.png
Source6:	bittorrent-4.4.0-readme.fedora
Patch0:		bittorrent-4.2.2-no-version-check.patch
Patch1:		bittorrent-4.4.0-appdir.patch
Patch2:		bittorrent-4.4.0-pkidir.patch
Patch3:		bittorrent-4.4.0-shellbang.patch
Patch4:		bittorrent-4.4.0-threads-warning.patch
Patch5:		bittorrent-4.4.0-fastresume.patch
Patch6:		bittorrent-4.4.0-syntax.patch
Patch7:		bittorrent-4.4.0-formatstrings.patch
Patch8:		bittorrent-4.4.0-bencode-float.patch
Patch9:		bittorrent-4.4.0-keyerror.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildArch:	noarch
BuildRequires:	python-devel >= 2.4.0, desktop-file-utils, gettext
Requires:	python-crypto

Provides:	python-khashmir = %{version}-%{release}
Obsoletes:	python-khashmir < %{version}-%{release}

Requires(pre): /usr/bin/getent /usr/sbin/groupadd /usr/sbin/useradd /usr/sbin/usermod
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig

%description
BitTorrent is a tool for distributing files. It's extremely easy to use -
downloads are started by clicking on hyperlinks. Whenever more than one person
is downloading at once they send pieces of the file(s) to each other, thus
relieving the central server's bandwidth burden. Even with many simultaneous
downloads, the upload burden on the central server remains quite small, since
each new downloader introduces new upload capacity.

%package gui
Summary:	GUI versions of the BitTorrent file transfer tools
Group:		Applications/Internet
Requires:	pygtk2 >= 2.6.0
Requires:	%{name} = %{version}-%{release}
Obsoletes:	BitTorrent < %{version}-%{release}, BitTorrent-gui < %{version}-%{release}
Provides:	BitTorrent = %{version}-%{release}, BitTorrent-gui = %{version}-%{release}

Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils

%description gui
BitTorrent is a tool for distributing files. It's extremely easy to use -
downloads are started by clicking on hyperlinks. Whenever more than one person
is downloading at once they send pieces of the file(s) to each other, thus
relieving the central server's bandwidth burden. Even with many simultaneous
downloads, the upload burden on the central server remains quite small, since
each new downloader introduces new upload capacity.

This package contains the graphical versions of the BitTorrent tools.

%prep
%setup -q -n BitTorrent-%{version}
%{__cp} -p %{SOURCE1} %{SOURCE3} %{SOURCE4} %{SOURCE5} .
%{__cp} -p %{SOURCE6} README.Fedora

# Prevent phone-home new version check
%patch0 -p1 -b .versioncheck

# Our package is "bittorrent", not "BitTorrent"
%patch1 -p1 -b .packagename

# Put public key in standard place
%patch2 -p1 -b .keydir
%{__sed} -i -e 's,@@PKIDIR@@,%{pkidir},' BitTorrent/NewVersion.py

# Remove useless shellbangs
%patch3 -p1 -b .shellbang

# Fix some deprecation warnings from pygtk2
%patch4 -p1 -b .thread-warnings

# Write fastresume data properly so that it's recognized at next startup
%patch5 -p1 -b .fastresume

# Fix syntax error on python 2.6
%patch6 -p1 -b .syntax

# Fix format strings that can't be properly translated
# Not much point doing this really as translations don't work anyway and
# it doesn't prevent the build itself from working
%if 0
%patch7 -p1 -b .strings
%endif

# Add bencode support for floating point values (#451496)
%patch8 -p1 -b .float

# Fix keyerror on tracker (#451496)
%patch9 -p1 -b .keyerror

# Update icon
%{__sed} -i -e 's,bittorrent\.png,%{_datadir}/pixmaps/bittorrent-%{version}/logo/bittorrent_48.png,' \
	bittorrent.desktop

# Create options files for initscripts
%{__cat} <<EOF >bittorrent.sysconfig
SEEDDIR=%{bt_datadir}
SEEDOPTS="--max_upload_rate 350 --display_interval 300"
SEEDLOG=%{_localstatedir}/log/bittorrent/btseed.log
TRACKPORT=6969
TRACKDIR=%{bt_datadir}
TRACKSTATEFILE=%{bt_statedir}/bttrack
TRACKLOG=%{_localstatedir}/log/bittorrent/bttrack.log
TRACKOPTS="--min_time_between_log_flushes 4.0 --show_names 1 --hupmonitor 1"
EOF

# Have the services' log files rotated
%{__cat} <<EOF >bittorrent.logrotate
%{_localstatedir}/log/bittorrent/btseed.log {
	notifempty
	missingok
	postrotate
		/sbin/service btseed condrestart 2>/dev/null >/dev/null || :
	endscript
}

%{_localstatedir}/log/bittorrent/bttrack.log {
	notifempty
	missingok
	postrotate
		/sbin/service bttrack condrestart 2>/dev/null >/dev/null || :
	endscript
}
EOF

%build
%{__python} setup.py build

%install
%{__rm} -rf %{buildroot}
%{__python} setup.py install -O1 --skip-build --root %{buildroot}
%{__install} -d -m 755 %{buildroot}%{_datadir}/applications
%{__install} -d -m 755 %{buildroot}%{pkidir}/bittorrent
%{__install} -m 0644 public.key %{buildroot}%{pkidir}/bittorrent
/usr/bin/desktop-file-install \
	--vendor %{desktopvendor} \
	--dir %{buildroot}%{_datadir}/applications \
	bittorrent.desktop
%{__install} -d %{buildroot}%{bt_dir}
%{__install} -d %{buildroot}%{bt_datadir}
%{__install} -d %{buildroot}%{bt_statedir}
%{__install} -d %{buildroot}%{_localstatedir}/{run,log/bittorrent}
%{__install} -m 0755 -D btseed.init %{buildroot}%{_initrddir}/btseed
%{__install} -m 0755 -D bttrack.init %{buildroot}%{_initrddir}/bttrack
%{__install} -m 0644 -D bittorrent.sysconfig %{buildroot}%{_sysconfdir}/sysconfig/bittorrent
%{__install} -m 0644 -D bittorrent.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/bittorrent
%{__install} -m 0644 -D bittorrent.png \
	%{buildroot}%{_datadir}/pixmaps/bittorrent-%{version}/logo/bittorrent_48.png
# add symlink for bittorrent.png required by desktop entry
%{__ln_s} bittorrent-%{version}/logo/bittorrent_48.png %{buildroot}%{_datadir}/pixmaps/bittorrent.png
# pidof doesn't find scripts with hyphenated names, so make some convenience links for initscripts
%{__ln_s} bittorrent-tracker %{buildroot}%{_bindir}/bttrack
%{__ln_s} launchmany-console %{buildroot}%{_bindir}/btseed
%{find_lang} bittorrent
# include egg-info if present
if [ -f %{buildroot}%{python_sitelib}/BitTorrent-%{version}-*.egg-info ]; then
	echo %{buildroot}%{python_sitelib}/BitTorrent-%{version}-*.egg-info |
		%{__sed} -e 's|^%{buildroot}||'
fi >> bittorrent.lang

%clean
%{__rm} -rf %{buildroot}

%pre
/usr/bin/getent group torrent >/dev/null || /usr/sbin/groupadd -r torrent
/usr/bin/getent passwd torrent >/dev/null || \
	/usr/sbin/useradd -r -s /sbin/nologin -d %{bt_dir} -g torrent \
		-c "BitTorrent Seed/Tracker" torrent
# Fix homedir for upgrades
/usr/sbin/usermod --home %{bt_dir} torrent &>/dev/null
exit 0

%post
/sbin/chkconfig --add btseed  || :
/sbin/chkconfig --add bttrack || :

%preun
if [ $1 -eq 0 ]; then
	%{_initrddir}/btseed  stop &>/dev/null || :
	%{_initrddir}/bttrack stop &>/dev/null || :
	/sbin/chkconfig --del btseed  || :
	/sbin/chkconfig --del bttrack || :
fi

%postun
if [ $1 -gt 0 ]; then
	%{_initrddir}/btseed  condrestart &>/dev/null || :
	%{_initrddir}/bttrack condrestart &>/dev/null || :
fi

%post gui
/usr/bin/update-desktop-database %{_datadir}/applications &>/dev/null || :

%postun gui
/usr/bin/update-desktop-database %{_datadir}/applications &>/dev/null || :

%files -f bittorrent.lang
%defattr(-,root,root,-)
%doc README.txt credits.txt credits-l10n.txt LICENSE.txt TRACKERLESS.txt
%doc README.Fedora
%{_bindir}/bittorrent-console
%{_bindir}/bittorrent-curses
%{_bindir}/bittorrent-tracker
%{_bindir}/changetracker-console
%{_bindir}/launchmany-console
%{_bindir}/launchmany-curses
%{_bindir}/maketorrent-console
%{_bindir}/torrentinfo-console
%{_bindir}/bttrack
%{_bindir}/btseed
%{pkidir}/bittorrent
%dir %{python_sitelib}/BitTorrent/
%{python_sitelib}/BitTorrent/*.py*
%{python_sitelib}/khashmir/
%attr(-,torrent,torrent) %dir %{bt_dir}/
%attr(-,torrent,torrent) %dir %{bt_datadir}/
%attr(-,torrent,torrent) %dir %{bt_statedir}/
%attr(-,torrent,torrent) %dir %{_localstatedir}/log/bittorrent/
%{_initrddir}/btseed
%{_initrddir}/bttrack
%config(noreplace) %{_sysconfdir}/logrotate.d/bittorrent
%config(noreplace) %{_sysconfdir}/sysconfig/bittorrent

%files gui
%defattr(-,root,root,-)
%{_bindir}/bittorrent
%{_bindir}/maketorrent
%{_datadir}/pixmaps/bittorrent.png
%{_datadir}/pixmaps/bittorrent-%{version}/
%{_datadir}/applications/%{desktopvendor}-bittorrent.desktop

%changelog
* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.4.0-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Apr 24 2009 Paul Howarth <paul@city-fan.org> 4.4.0-12
- Add icon back in menu entry

* Mon Apr  6 2009 Paul Howarth <paul@city-fan.org> 4.4.0-11
- Add support for floating point values in bencode (#451496), resolving
  tracebacks with KeyError: <type 'float'>
  (thanks to Oleg Aprotskiy for the patch)
- Don't apply format string patch; it serves no purpose really
- Fix for KeyError: 'max_incomplete' in tracker (#451496)
- Define RPM macros in global context in spec file

* Tue Feb 24 2009 Paul Howarth <paul@city-fan.org> 4.4.0-10
- Fix syntax issues causing failure to build for Fedora 11
- Update format strings to enable re-ordering of parameters in translations
- Add additional categories FileTransfer and P2P in desktop entry (#487789)

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.4.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 4.4.0-8
- Rebuild for Python 2.6

* Fri Aug 15 2008 Paul Howarth <paul@city-fan.org> 4.4.0-7
- Use new scriptlets for user/group creation
- Fix up torrent homedir silently (#457563)
- Create a pidfile for btseed (#458926)
- Remove tracker pidfile when service is stopped (no need to include the
  %%ghost-ed pidfile now)
- Use %%{_initrddir} instead of %%{_sysconfdir}/rc.d/init.d
- Call initscripts directly instead of via /sbin/service to reduce scriptlet
  dependencies

* Tue Apr  8 2008 Paul Howarth <paul@city-fan.org> 4.4.0-6
- Default data directory moved back out of /srv
  (to %%{_localstatedir}/lib/bittorrent)
  (http://fedoraproject.org/wiki/PackagingDrafts/NoBitsInSrv)
- Change torrent user's home directory from %%{_localstatedir}/spool/bittorrent
  to %%{_localstatedir}/lib/bittorrent, fix the home directory of any existing
  torrent user, and don't include %%{_localstatedir}/spool/bittorrent in the
  package any more
- Include egg-info if present (#440906)
- Fix some deprecation warnings from pygtk2
- Include credits-l10n.txt document (#237256)
- Write fastresume data properly so that it's recognized next time (#245421)
- Add README.Fedora to explain how to use the track/seed services (#430849)
- Use short license name to pacify rpmlint

* Sun Mar 25 2007 Paul Howarth <paul@city-fan.org> 4.4.0-5
- Own directory /srv/bittorrent (#233824)

* Tue Feb 27 2007 Paul Howarth <paul@city-fan.org> 4.4.0-4
- Downgrade to 4.4.0 due to incompatibility between the GUI & wx 2.8 (#223623)
- Revert no-version-check patch to 4.2.2 version
- Rework appdir, pkidir, and shellbang patches to apply against 4.4.0
- Remove wxversion patch
- Remove BTL, Zeroconf, and GUI_wx modules from files list
- Don't provide/obsolete python-BTL
- Use unbundled 48x48 icon
- Reinstate pygtk2 dependency for GUI subpackage
- Drop python-twisted-{core,web} deps for main package, and wxPython for GUI
- Drop python-twisted-core buildreq

* Fri Jan 25 2007 Paul Howarth <paul@city-fan.org> 5.0.5-2
- Use new icon for menu; icon cache scriptlets no longer needed
- Prefer wx version 2.6.x but try to use later versions if necessary
- Don't package GUI python code in main package was well as gui subpackage

* Fri Jan 19 2007 Paul Howarth <paul@city-fan.org> 5.0.5-1
- Update to 5.0.5
- Cosmetic spec file tweaks

* Thu Jan 18 2007 Paul Howarth <paul@city-fan.org> 5.0.4-1
- Update to 5.0.4
- StartupNotify=true in desktop file
- Source is now on download.bittorrent.com, not www.bittorrent.com
- Update no-version-check patch
- Use patches rather than scripted edits to detect changes more easily
- Strip out support for all distributions that don't have python >= 2.4, i.e.
  Fedora < 4 and RHEL4
- New python package BTL
- Add new deps python-twisted-{core,web} for main package, and wxPython for GUI
- Include Zeroconf python code
- Include GUI_wx in GUI subpackage
- pygtk2 no longer needed for GUI subpackage
- GUI subpackage provides BitTorrent-gui as well as obsoleting it
- Don't use categories X-Fedora or Application in the desktop file
- %%{_localstatedir}/spool/bittorrent must exist and be writable by user
  torrent to store config settings (#231697)
- Separate credits file for translators no longer included

* Sat Dec  9 2006 Paul Howarth <paul@city-fan.org> 4.4.0-3
- Fixups for build with python 2.5 on Rawhide

* Tue Aug 29 2006 Paul Howarth <paul@city-fan.org> 4.4.0-2
- Don't need python-devel buildreq
- Don't %%ghost .pyo files

* Thu Feb  2 2006 Paul Howarth <paul@city-fan.org> 4.4.0-1
- Update to 4.4.0
- Hardcode /usr/sbin in useradd dependency path
- Update %%description
- GUI subpackage now requires pygtk2 >= 2.6.0 so no FC3 or RHEL4 build
- Specify explicit path for runuser in initscripts
- Merge /etc/sysconfig/{btseed,bttrack} into /etc/sysconfig/bittorrent
- Merge /etc/logrotate.d/{btseed,bttrack} into /etc/logrotate.d/bittorrent
- Fix initscript for bttrack to allow for pidfile creation
- Ghost /var/run/bittorrent-tracker.pid so it gets deleted on package removal
- Add comments in %%prep
- Remove shellbangs from python files to reduce rpmlint output
- Replace $RPM_BUILD_ROOT with %%{buildroot} (packager's personal preference)

* Tue Dec 20 2005 Paul Howarth <paul@city-fan.org> 4.2.2-2
- Add patch to prevent phoning home for new version checks

* Mon Dec 19 2005 Paul Howarth <paul@city-fan.org> 4.2.2-1
- Update to 4.2.2

* Tue Dec  6 2005 Paul Howarth <paul@city-fan.org> 4.2.1-1
- Update to 4.2.1
- Source now at www.bittorrent.com rather than sourceforge

* Wed Nov 23 2005 Paul Howarth <paul@city-fan.org> 4.2.0-1
- update to 4.2.0

* Wed Nov 16 2005 Paul Howarth <paul@city-fan.org> 4.1.8-1
- update to 4.1.8

* Thu Nov  3 2005 Paul Howarth <paul@city-fan.org> 4.1.7-1
- update to 4.1.7
- don't use macros in build-time and scriptlet command paths

* Thu Oct 13 2005 Paul Howarth <paul@city-fan.org> 4.1.6-2
- append to seed log file instead of overwriting it

* Thu Oct 13 2005 Paul Howarth <paul@city-fan.org> 4.1.6-1
- update to 4.1.6

* Thu Aug 18 2005 Paul Howarth <paul@city-fan.org> 4.1.4-1
- update to 4.1.4
- all "binaries" renamed; initscripts & desktop entry changed accordingly
- don't need to edit out "env python2"... stuff
- appdir now set in platform.py instead of __init__.py
- add credits-l10n.txt as %%doc
- add python-crypto dependency
- add public.key in appropriate place
- tweak Fedora/RHEL conditional build selection

* Fri Jul 15 2005 Paul Howarth <paul@city-fan.org> 4.1.3-1
- update to 4.1.3

* Fri Jul 15 2005 Paul Howarth <paul@city-fan.org> 4.1.2-6
- provides should be version-release tagged too

* Tue Jul 11 2005 Paul Howarth <paul@city-fan.org> 4.1.2-5
- move icon to %%{_datadir}/icons/hicolor/48x48/apps instead of
  %%{_datadir}/pixmaps and update icon cache on installation if
  necessary (#162465)
- no need to set CFLAGS in %%build for noarch package
- don't offer build option not to delete usr/group on uninstall
- don't generate redundant python-abi dependency for FC >= 4

* Thu Jul  7 2005 Paul Howarth <paul@city-fan.org> 4.1.2-4
- bump and rebuild

* Tue Jul  5 2005 Paul Howarth <paul@city-fan.org> 4.1.2-3
- obsolete python-khashmir based on version-release, not just version

* Mon Jul  4 2005 Paul Howarth <paul@city-fan.org> 4.1.2-2
- add Provides/Obsoletes for python-khashmir for clean upgrades from split
  bittorrent packages

* Mon Jun 13 2005 Paul Howarth <paul@city-fan.org> 4.1.2-1
- update to 4.1.2
- add gettext build requirement for translations

* Mon Jun  6 2005 Paul Howarth <paul@city-fan.org> 4.1.1-3
- don't delete user/group torrent on uninstall
  (see https://www.redhat.com/archives/fedora-extras-commits/2005-June/msg00271.html)

* Thu Jun  2 2005 Paul Howarth <paul@city-fan.org> 4.1.1-2
- tidy up description text
- improved initscripts (#158273)
- for versions on Fedora Core >= 4 or RHEL, put server data under /srv rather
  than %%{_localstatedir}
- separate logs/logrotate scripts for tracker and seeder
- have the gui subpackage obsolete the official BitTorrent RPM package, which
  is called BitTorrent, includes the GUI in the same package and is built
  using python's dist tools and hence doesn't include all dependencies,
  provide initscripts etc.; this provides a clean upgrade path to Extras

* Tue May 31 2005 Paul Howarth <paul@city-fan.org> 4.1.1-1
- update to 4.1.1
- add "khashmir" python library
- add TRACKERLESS.txt as %%doc
- add translations

* Tue May 24 2005 Paul Howarth <paul@city-fan.org> 4.0.2-1
- update to 4.0.2

* Mon May 23 2005 Paul Howarth <paul@city-fan.org> 4.0.1-2
- use macros consistently throughout
- add initscripts so users can easily set up trackers and seeders
  on their own (#158273)
- add user torrent for tracker/seeder
- add logrotate script for tracker

* Wed May 18 2005 Paul Howarth <paul@city-fan.org> 4.0.1-1
- new upstream release 4.0.1 (#157632)
- add dist tag
- source now found on sourceforge.net
- move post/postun scriptlets to -gui subpackage
- bttest.py removed upstream

* Tue Mar 15 2005 Michael Schwendt <mschwendt[AT]users.sf.net> - 4.0.0-2
- add desktop file, desktop menu icon, post/postun scriptlets

* Mon Mar 14 2005 David Hill <djh[at]ii.net> - 4.0.0-1
- update to 4.0.0, no longer requires wxPythonGTK

* Wed Dec 22 2004 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:3.4.1-3.a
- x86_64: Fix python dependency, replace with python-abi dependency.

* Mon Mar 29 2004 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:3.4.1-0.fdr.2.a
- Changed Requires wxPythonGTK to wxPython (bug 1416).
- Converted spec file to UTF-8.

* Thu Mar 25 2004 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:3.4.1-0.fdr.1.a
- Updated to 3.4.1a.
- Brought in line with the Python spec template.
- Fixed group and missing epoch in requires for gui subpackage.
- Eliminated multiple copies of README.txt.
- Eliminated perl BuildReq.

* Wed Jul 16 2003 Seth Vidal <skvidal@phy.duke.edu>
- rebuild under 7.3
- some fixes

* Wed Jul 16 2003 Warren Togami <warren@togami.com> 3.2.1-0.fdr.2.b
- Fedoraize

* Wed Jul 16 2003 Seth Vidal <skvidal@phy.duke.edu>
- rebuilt on rhl 9 - testing

* Fri May 30 2003 Peter Hanecak <hanecak@megaloman.sk> 3.2.1b-1
- adapted to Doors Linux

* Sun Mar 30 2003 Götz Waschk <waschk@linux-mandrake.com> 3.2.1b-1mdk
- split out gui tools to remove wxPythonGTK dep from the main package
- new version

* Fri Mar 28 2003 Frederic Lepied <flepied@mandrakesoft.com> 3.2-1mdk
- 3.2

* Wed Mar 26 2003 Frederic Lepied <flepied@mandrakesoft.com> 3.1-1mdk
- initial packaging
